mtd/drivers/mtd/nand nand_base.c,1.120,1.121

gleixner at infradead.org gleixner at infradead.org
Wed Oct 6 15:53:14 EDT 2004


Update of /home/cvs/mtd/drivers/mtd/nand
In directory phoenix.infradead.org:/tmp/cvs-serv2765

Modified Files:
	nand_base.c 
Log Message:
Fix 4th write cycle for devices > 128MB. Prointed out by Brad Beveridge <bbeveridge at bluewatersys.com>

Index: nand_base.c
===================================================================
RCS file: /home/cvs/mtd/drivers/mtd/nand/nand_base.c,v
retrieving revision 1.120
retrieving revision 1.121
diff -u -r1.120 -r1.121
--- nand_base.c	25 Sep 2004 00:10:34 -0000	1.120
+++ nand_base.c	6 Oct 2004 19:53:11 -0000	1.121
@@ -543,8 +543,8 @@
 		if (page_addr != -1) {
 			this->write_byte(mtd, (unsigned char) (page_addr & 0xff));
 			this->write_byte(mtd, (unsigned char) ((page_addr >> 8) & 0xff));
-			/* One more address cycle for higher density devices */
-			if (this->chipsize & 0x0c000000) 
+			/* One more address cycle for devices > 32MiB */
+			if (this->chipsize > (32 << 20))
 				this->write_byte(mtd, (unsigned char) ((page_addr >> 16) & 0x0f));
 		}
 		/* Latch in address */





More information about the linux-mtd-cvs mailing list